==> cowmgr-0.0.9.tar.gz: cowmgr-0.0.9/merge/tile_merge.h <==
#ifndef FOOOOO
#define FOOOOO

#include "cow.h"
#include "swap.h"
#include "buffer.h"
#include "areas.h"
#include "buffer_tile.h"
#include "buffer_ptr.h"


#define TILE_HEIGHT 64
#define TILE_WIDTH 64

#define TileManager GimpBuffer

typedef struct
{
  GimpBuffer * b;

  GimpArea focus;
  GimpArea bounds;

  GimpPoint tile;
  
  gboolean used;
  
  GimpMemPtr * d;
  gint rowstride;
  gint pixstride;

} Tile;



TileManager * dup_buffer (TileManager * src);


#define tile_swap_add(f, a, b) gimp_memory_init (f)
#define tile_swap_exit()




#define tile_manager_new(w,h,t)     (TileManager*) gimp_tile_buffer_new ((t),(w),(h),64,64)
#define tile_manager_destroy        gimp_buffer_delete
#define tile_manager_level_width    gimp_buffer_width
#define tile_manager_level_height   gimp_buffer_height
#define tile_manager_level_bpp      gimp_buffer_bpp

#define tile_manager_set_validate_proc(t,p)   (t)->vfunc = (p)
#define tile_manager_set_user_data(t,d)       (t)->vdata = (d)
#define tile_manager_get_user_data(t)         (t)->vdata
#define tile_manager_fixme_x(t)               (t)->qq_x
#define tile_manager_fixme_y(t)               (t)->qq_y

Tile*
tile_manager_get_tile (TileManager *tm,
		       int          xpixel,
		       int          ypixel,
		       int          wantread,
		       int          wantwrite);

#define tile_manager_get(a,b,c,d) NULL
#define tile_manager_get_async(a,b,c)

#define tile_invalidate_tile(a, b, c, d)
#define tile_mark_valid(a)
#define tile_is_valid(t) TRUE

void   tile_release      (Tile *t, int dirty);
void * tile_data_pointer (Tile *t, int x, int y);

#define tile_bpp(t)      gimp_buffer_bpp ((t)->b)
#define tile_ewidth(t)   gimp_buffer_tilewidth ((t)->b)
#define tile_eheight(t)  gimp_buffer_tileheight ((t)->b)
#define tile_size(t)     (tile_ewidth(t) * tile_eheight(t) * tile_bpp(t))



#endif

==> cowmgr-0.0.10.tar.gz: cowmgr-0.0.10/merge/tile_merge.h <==
#ifndef FOOOOO
#define FOOOOO

#include "cow.h"
#include "swap.h"
#include "buffer.h"
#include "areas.h"
#include "buffer_tile.h"
#include "buffer_flat.h"
#include "buffer_ptr.h"


#define TILE_HEIGHT 64
#define TILE_WIDTH 64

#define TileManager GimpBuffer

typedef struct
{
  GimpBuffer * b;

  GimpArea focus;
  GimpArea bounds;

  GimpPoint tile;
  
  gboolean used;
  
  GimpMemPtr * d;
  gint rowstride;
  gint pixstride;

} Tile;



TileManager * dup_buffer (TileManager * src);


#define tile_swap_add(f, a, b) gimp_memory_init (f)
#define tile_swap_exit()




#define tile_manager_new(w,h,t)     (TileManager*) gimp_tile_buffer_new ((t),(w),(h),64,64)
#define tile_manager_destroy        gimp_buffer_delete
#define tile_manager_level_width    gimp_buffer_width
#define tile_manager_level_height   gimp_buffer_height
#define tile_manager_level_bpp      gimp_buffer_bpp

#define tile_manager_set_validate_proc(t,p)   (t)->vfunc = (p)
#define tile_manager_set_user_data(t,d)       (t)->vdata = (d)
#define tile_manager_get_user_data(t)         (t)->vdata
#define tile_manager_fixme_x(t)               (t)->qq_x
#define tile_manager_fixme_y(t)               (t)->qq_y

Tile*
tile_manager_get_tile (TileManager *tm,
		       int          xpixel,
		       int          ypixel,
		       int          wantread,
		       int          wantwrite);

#define tile_manager_get(a,b,c,d) NULL
#define tile_manager_get_async(a,b,c)

#define tile_invalidate_tile(a, b, c, d)
#define tile_mark_valid(a)
#define tile_is_valid(t) TRUE

void   tile_release      (Tile *t, int dirty);
void * tile_data_pointer (Tile *t, int x, int y);

#define tile_bpp(t)      gimp_buffer_bpp ((t)->b)
#define tile_ewidth(t)   gimp_buffer_tilewidth ((t)->b)
#define tile_eheight(t)  gimp_buffer_tileheight ((t)->b)
#define tile_size(t)     (tile_ewidth(t) * tile_eheight(t) * tile_bpp(t))



/*=============================================================*/


#define TempBuf GimpBuffer
#define MaskBuf GimpBuffer


TempBuf * temp_buf_new (int, int, int, int, int, unsigned char *);
MaskBuf * mask_buf_new (int, int);

#define temp_buf_width gimp_buffer_width
#define temp_buf_height gimp_buffer_height
#define temp_buf_bytes gimp_buffer_bpp
#define temp_buf_free gimp_buffer_delete
#define mask_buf_free gimp_buffer_delete

/* fix up callers */
#define temp_buf_data(t) foobar
#define mask_buf_data(t) foobar
#define temp_buf_resize(t,a,b,c,d,e) foobar

/* unused */
#define temp_buf_copy_area(t,t2,a,b,c,d,e)
#define temp_buf_copy(t,t2)

/* ignore these */
#define temp_buf_swap(t)
#define temp_buf_unswap(t);
#define temp_buf_swap_free(t)
#define swapping_free()

/* broken broken */
#define temp_buf_fixme_x(t)               (t)->qq_x
#define temp_buf_fixme_y(t)               (t)->qq_y


#endif
